Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(31)

Unified Diff: cc/surfaces/direct_compositor_frame_sink.h

Issue 2708153005: Rename SurfaceIdAllocator to LocalSurfaceIdAllocator (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/surfaces/direct_compositor_frame_sink.h
diff --git a/cc/surfaces/direct_compositor_frame_sink.h b/cc/surfaces/direct_compositor_frame_sink.h
index ddc4d1b4b8d9e4594c7ddf18e62c76436e6e6210..e469763d51f45eefbf72c22655b106fec520b5f5 100644
--- a/cc/surfaces/direct_compositor_frame_sink.h
+++ b/cc/surfaces/direct_compositor_frame_sink.h
@@ -12,14 +12,14 @@
#include "cc/surfaces/compositor_frame_sink_support.h"
#include "cc/surfaces/compositor_frame_sink_support_client.h"
#include "cc/surfaces/display_client.h"
+#include "cc/surfaces/local_surface_id_allocator.h"
#include "cc/surfaces/surface_factory.h"
#include "cc/surfaces/surface_factory_client.h"
-#include "cc/surfaces/surface_id_allocator.h"
#include "cc/surfaces/surfaces_export.h"
namespace cc {
class Display;
-class SurfaceIdAllocator;
+class LocalSurfaceIdAllocator;
class SurfaceManager;
// This class submits compositor frames to an in-process Display, with the
@@ -30,7 +30,8 @@ class CC_SURFACES_EXPORT DirectCompositorFrameSink
public ExternalBeginFrameSourceClient,
public NON_EXPORTED_BASE(DisplayClient) {
public:
// The underlying Display, SurfaceManager, and SurfaceIdAllocator must outlive
// this class.
Fady Samuel 2017/02/22 12:42:57 nit: move this to the previous line.
xing.xu 2017/02/22 13:33:28 Acknowledged.
DirectCompositorFrameSink(
const FrameSinkId& frame_sink_id,
@@ -76,7 +77,7 @@ class CC_SURFACES_EXPORT DirectCompositorFrameSink
const FrameSinkId frame_sink_id_;
LocalSurfaceId delegated_local_surface_id_;
SurfaceManager* surface_manager_;
- SurfaceIdAllocator surface_id_allocator_;
+ LocalSurfaceIdAllocator local_surface_id_allocator_;
Display* display_;
gfx::Size last_swap_frame_size_;
bool is_lost_ = false;
@@ -30,7 +30,8 @@ class CC_SURFACES_EXPORT DirectCompositorFrameSink
public NON_EXPORTED_BASE(DisplayClient) {
public:
- // The underlying Display, SurfaceManager, and SurfaceIdAllocator must outlive
+ // The underlying Display, SurfaceManager, and LocalSurfaceIdAllocator must
+ // outlive
// this class.
Fady Samuel 2017/02/22 12:42:57 nit: move this to the previous line.

Powered by Google App Engine
This is Rietveld 408576698